TransHRegularizer
=================

.. currentmodule:: pykeen.regularizers

.. autoclass:: TransHRegularizer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransHRegularizer.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransHRegularizer.forward
      ~TransHRegularizer.update

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: update
